"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const prettier_1 = __importDefault(require("prettier"));
const axios_1 = __importDefault(require("axios"));
const pascalcase_1 = __importDefault(require("pascalcase"));
const template_1 = require("./templates/template");
const serviceHeader_1 = require("./templates/serviceHeader");
const utils_1 = require("./utils");
const requestCodegen_1 = require("./requestCodegen");
const componentsCodegen_1 = require("./componentsCodegen");
const definitionCodegen_1 = require("./definitionCodegen");
const defaultOptions = {
    serviceNameSuffix: 'Service',
    enumNamePrefix: 'Enum',
    methodNameMode: 'operationId',
    outputDir: './service',
    fileName: 'index.ts',
    useStaticMethod: true,
    useCustomerRequestInstance: false,
    modelMode: 'interface',
    include: [],
    strictNullChecks: true,
    useClassTransformer: false,
    extendGenericType: []
};
function codegen(params) {
    return __awaiter(this, void 0, void 0, function* () {
        console.time('finish');
        let err;
        let swaggerSource;
        utils_1.setDefinedGenericTypes(params.extendGenericType);
        // 获取接口定义文件
        if (params.remoteUrl) {
            const { data: swaggerJson } = yield axios_1.default({ url: params.remoteUrl, responseType: 'text' });
            if (Object.prototype.toString.call(swaggerJson) === '[object String]') {
                fs.writeFileSync('./cache_swagger.json', swaggerJson);
                swaggerSource = require(path.resolve('./cache_swagger.json'));
            }
            else {
                swaggerSource = swaggerJson;
            }
        }
        else if (params.source) {
            swaggerSource = params.source;
        }
        else {
            throw new Error('remoteUrl or source must have a value');
        }
        const options = Object.assign(Object.assign({}, defaultOptions), params);
        let apiSource = options.useCustomerRequestInstance ? serviceHeader_1.customerServiceHeader(options) : serviceHeader_1.serviceHeader(options);
        // 判断是否是openApi3.0或者swagger3.0
        const isV3 = utils_1.isOpenApi3(params.openApi || swaggerSource.openapi || swaggerSource.swagger);
        console.log('isV3', isV3);
        let requestClasses = Object.entries(requestCodegen_1.requestCodegen(swaggerSource.paths, isV3));
        const { models, enums } = isV3
            ? componentsCodegen_1.componentsCodegen(swaggerSource.components)
            : definitionCodegen_1.definitionsCodeGen(swaggerSource.definitions);
        if (options.include && options.include.length > 0) {
            // 接口过滤入口
            let reqSource = '';
            let defSource = '';
            let allModel = Object.values(models);
            // console.log(allModel)
            let allEnum = Object.values(enums);
            let allImport = [];
            // 处理接口
            options.include.forEach(item => {
                let includeClassName = '';
                let includeRequests = null;
                if (Object.prototype.toString.call(item) === '[object String]') {
                    includeClassName = item;
                }
                else {
                    for (let k of Object.keys(item)) {
                        includeClassName = k;
                        includeRequests = item[k];
                    }
                }
                for (let [className, requests] of requestClasses) {
                    if (pascalcase_1.default(includeClassName) !== className)
                        continue;
                    let text = '';
                    for (let req of requests) {
                        const reqName = options.methodNameMode == 'operationId' ? req.operationId : req.name;
                        if (includeRequests) {
                            if (includeRequests.includes(reqName)) {
                                text += template_1.requestTemplate(reqName, req.requestSchema, options);
                                // generate ref definition model
                                let imports = utils_1.findDeepRefs(req.requestSchema.parsedParameters.imports, allModel, allEnum);
                                allImport = allImport.concat(imports);
                            }
                        }
                        else {
                            text += template_1.requestTemplate(reqName, req.requestSchema, options);
                            let imports = utils_1.findDeepRefs(req.requestSchema.parsedParameters.imports, allModel, allEnum);
                            allImport = allImport.concat(imports);
                        }
                    }
                    text = template_1.serviceTemplate(className + options.serviceNameSuffix, text);
                    reqSource += text;
                }
            });
            // 处理类和枚举
            allModel.forEach(item => {
                if (allImport.includes(item.name)) {
                    const text = params.modelMode === 'interface'
                        ? template_1.interfaceTemplate(item.value.name, item.value.props, [], params.strictNullChecks)
                        : template_1.classTemplate(item.value.name, item.value.props, [], params.strictNullChecks, options.useClassTransformer, options.generateValidationModel);
                    defSource += text;
                }
            });
            allEnum.forEach(item => {
                if (allImport.includes(item.name)) {
                    let text = '';
                    if (item.value) {
                        if (item.value.type == 'string') {
                            text = template_1.enumTemplate(item.value.name, item.value.enumProps, options.enumNamePrefix);
                        }
                        else {
                            text = template_1.typeTemplate(item.value.name, item.value.enumProps, options.enumNamePrefix);
                        }
                    }
                    else {
                        text = item.content || '';
                    }
                    defSource += text;
                }
            });
            apiSource += reqSource + defSource;
            writeFile(options.outputDir || '', options.fileName || '', format(apiSource, options));
        }
        else {
            // 常规入口
            try {
                // 处理接口
                requestClasses.forEach(([className, requests]) => {
                    let text = '';
                    requests.forEach(req => {
                        const reqName = options.methodNameMode == 'operationId' ? req.operationId : req.name;
                        text += template_1.requestTemplate(reqName, req.requestSchema, options);
                    });
                    text = template_1.serviceTemplate(className + options.serviceNameSuffix, text);
                    apiSource += text;
                });
                // 处理类和枚举
                Object.values(models).forEach(item => {
                    const text = params.modelMode === 'interface'
                        ? template_1.interfaceTemplate(item.value.name, item.value.props, [], params.strictNullChecks)
                        : template_1.classTemplate(item.value.name, item.value.props, [], params.strictNullChecks, options.useClassTransformer, options.generateValidationModel);
                    apiSource += text;
                });
                Object.values(enums).forEach(item => {
                    let text = '';
                    if (item.value) {
                        if (item.value.type == 'string') {
                            text = template_1.enumTemplate(item.value.name, item.value.enumProps, options.enumNamePrefix);
                        }
                        else {
                            text = template_1.typeTemplate(item.value.name, item.value.enumProps, options.enumNamePrefix);
                        }
                    }
                    else {
                        text = item.content || '';
                    }
                    apiSource += text;
                });
                writeFile(options.outputDir || '', options.fileName || '', format(apiSource, options));
            }
            catch (error) {
                console.log('error', error);
                err = error;
            }
        }
        if (fs.existsSync('./cache_swagger.json')) {
            fs.unlinkSync('./cache_swagger.json');
        }
        console.timeEnd('finish');
        if (err) {
            throw err;
        }
    });
}
exports.codegen = codegen;
function writeFile(fileDir, name, data) {
    if (!fs.existsSync(fileDir)) {
        fs.mkdirSync(fileDir);
    }
    const filename = path.join(fileDir, name);
    console.log('filename', filename);
    fs.writeFileSync(filename, data);
}
function format(text, options) {
    if (options.format) {
        console.log('use custom formatter');
        return options.format(text);
    }
    console.log('use default formatter');
    return prettier_1.default.format(text, {
        printWidth: 120,
        tabWidth: 2,
        parser: 'typescript',
        trailingComma: 'none',
        jsxBracketSameLine: false,
        semi: true,
        singleQuote: true
    });
    // return text
}
//# sourceMappingURL=index.js.map