"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
let definedGenericTypes = [];
const UniversalGenericTypes = ['IList', 'List'];
const AbpGenericTypes = ['IListResult', 'ListResultDto', 'IPagedResult', 'PagedResultDto'];
// 是否是接口类型
exports.isOpenApiGenerics = (s) => /^.+\[.+\]$/.test(s) || /^.+\«.+\»$/.test(s) || /^.+\<.+\>$/.test(s);
exports.isGenerics = (s) => /^.+\<.+\>$/.test(s);
exports.isDefinedGenericTypes = (x) => definedGenericTypes.some(i => i === x);
function setDefinedGenericTypes(types = []) {
    definedGenericTypes.push(...UniversalGenericTypes, ...AbpGenericTypes, ...types);
}
exports.setDefinedGenericTypes = setDefinedGenericTypes;
/**
 * 分解泛型接口
 * @param definitionClassName
 */
function getGenericsClassNames(definitionClassName) {
    let str = '';
    let split_key = '';
    if (/^.+\[.+\]$/.test(definitionClassName)) {
        split_key = '[';
    }
    else if (/^.+\«.+\»$/.test(definitionClassName)) {
        split_key = '«';
    }
    else if (/^.+\<.+\>$/.test(definitionClassName)) {
        split_key = '<';
    }
    if (split_key !== '') {
        const splitIndex = definitionClassName.indexOf(split_key);
        // 泛型基类 PagedResultDto
        const interfaceClassName = definitionClassName.slice(0, splitIndex);
        // 泛型类型 T 的类型名称
        const TClassName = definitionClassName.slice(splitIndex + 1, -1);
        str = exports.isDefinedGenericTypes(interfaceClassName)
            ? `${interfaceClassName}<${refClassName(TClassName)}>`
            : trimString(RemoveSpecialCharacters(definitionClassName), '_', 'right');
    }
    else {
        // console.log('getGenericsClassNames', definitionClassName)
        str = toBaseType(trimString(RemoveSpecialCharacters(definitionClassName), '_', 'right'));
    }
    return str;
}
exports.getGenericsClassNames = getGenericsClassNames;
/**
 * 获取引用类型
 * @param s
 */
function refClassName(s) {
    var _a;
    let propType = (_a = s) === null || _a === void 0 ? void 0 : _a.slice(s.lastIndexOf('/') + 1);
    return exports.isOpenApiGenerics(propType)
        ? getGenericsClassNames(propType)
        : toBaseType(trimString(RemoveSpecialCharacters(propType), '_', 'right'));
}
exports.refClassName = refClassName;
/** 移除特殊字符 */
function RemoveSpecialCharacters(str) {
    var _a;
    return (_a = str) === null || _a === void 0 ? void 0 : _a.replace(/[`~!@#$%^&*()_+<>«»?:"{},.\/;'[\]]/g, '_');
}
exports.RemoveSpecialCharacters = RemoveSpecialCharacters;
function isBaseType(s) {
    return ['boolean', 'number', 'string', 'string', 'Date', 'any'].includes(s);
}
exports.isBaseType = isBaseType;
function toBaseType(s, format) {
    if (s === undefined || s === null || s.length === 0) {
        return 'any | null';
    }
    let result = '';
    switch (s) {
        case 'boolean':
        case 'bool':
        case 'Boolean':
            result = 'boolean';
            break;
        case 'array':
            result = '[]';
            break;
        case 'Int64':
        case 'int':
        case 'integer':
        case 'number':
            result = 'number';
            break;
        case 'Guid':
        case 'String':
        case 'string':
        case 'uuid':
            switch (format) {
                case 'date':
                case 'date-time':
                    result = 'Date';
                    break;
                default:
                    result = 'string';
            }
            break;
        case 'file':
            result = 'any';
            break;
        default:
            result = s;
            break;
    }
    return result;
}
exports.toBaseType = toBaseType;
function getMethodName(path) {
    const paths = path.split('/');
    for (let i = paths.length - 1; i >= 0; i--) {
        if (/\{.+\}/.test(paths[i]) === false) {
            return paths[i];
        }
    }
    return '';
}
exports.getMethodName = getMethodName;
function trimString(str, char, type) {
    if (char) {
        if (type == 'left') {
            return str.replace(new RegExp('^\\' + char + '+', 'g'), '');
        }
        else if (type == 'right') {
            return str.replace(new RegExp('\\' + char + '+$', 'g'), '');
        }
        return str.replace(new RegExp('^\\' + char + '+|\\' + char + '+$', 'g'), '');
    }
    return str.replace(/^\s+|\s+$/g, '');
}
exports.trimString = trimString;
function findDeepRefs(imports, allDefinition, allEnums) {
    let result = [];
    imports.forEach(model => {
        let ref = null;
        ref = allDefinition.find(item => model.startsWith(item.name));
        if (ref) {
            result.push(ref.name);
            if (ref.value.imports.length > 0) {
                result = result.concat(findDeepRefs(ref.value.imports, allDefinition, allEnums));
            }
        }
        else {
            ref = allEnums.find(item => model.startsWith(item.name));
            if (ref) {
                result.push(ref.name);
            }
        }
    });
    return result;
}
exports.findDeepRefs = findDeepRefs;
function isOpenApi3(version) {
    console.log('openApi version：', version);
    return version.startsWith('3.', 0);
}
exports.isOpenApi3 = isOpenApi3;
function getValidationModel(propName, prop, required) {
    let validationModel = {};
    let hasValidationRules = false;
    if (required && required.includes(propName)) {
        validationModel.required = true;
        hasValidationRules = true;
    }
    if (prop.maxLength) {
        validationModel.maxLength = prop.maxLength;
        hasValidationRules = true;
    }
    return hasValidationRules ? validationModel : null;
}
exports.getValidationModel = getValidationModel;
//# sourceMappingURL=utils.js.map